<template>
  <!--系统集成的系统日志页面-->
  <basic-container>
    <avue-crud :option="option"
               :table-loading="loading"
               :data="data"
               :page.sync="page"
               :permission="permissionList"
               ref="crud"
               @search-change="searchChange"
               @search-reset="searchReset"
               @selection-change="selectionChange"
               @current-change="currentChange"
               @size-change="sizeChange"
               @refresh-change="refreshChange"
               @on-load="onLoad">
    </avue-crud>
  </basic-container>
</template>

<script>
import {getList} from "@/api/docking/loge";
import {validatenull} from "@/util/validate";
import {mapGetters} from "vuex";

export default {
  name: "loge",
  data(){
    return {
      loading: false,
      query: {},
      selectionList: [],
      page: {
        pageSize: 20,
        currentPage: 1,
        total: 0
      },
      data:[],
      option: {
        height:'auto',
        calcHeight: 0,
        tip: false,
        searchShow: false,
        searchMenuSpan: 6,
        border: true,
        index: true,
        viewBtn: true,
        selection: false,
        dialogClickModal: false,
        menu:false,
        column: [
          {
            label: "数据编码",
            prop: "id",
            search: true,
            sortable:true,
            width:150
          },
          {
            label: "图号",
            prop: "uniqueCode",
            search: true,
            hide:true,
            sortable:true,
            width:150
          },
          {
            label: '分类代号',
            prop: 'classifyId',
            search: true,
            sortable:true,
            width: 250
          },
          {
            label: '分类名称',
            prop: 'classifyName',
            search: true,
            sortable:true,
            overHidden: true
          },
          {
            label: '集成系统编号',
            prop: 'systemCode',
            search: true,
            sortable:true,
            width: 150
          },
          {
            label: '集成系统名称',
            prop: 'systemName',
            search: true,
            sortable:true,
            width: 150
          },
          {
            label:'接口参数',
            prop:'paramString',
            overHidden:true,
            search: true,
            sortable:true,
            width: 150
          },
          {
            label:'返回参数',
            prop:'returnString',
            overHidden:true,
            search: true,
            sortable:true,
            width: 150
          },
          {
            label: '返回msg',
            prop: 'msg',
            overHidden: true
          },
          {
            label: '记录时间',
            prop: 'createTime',
            sortable:true,
            width: 160
          },
          {
            label: '是否推送成功',
            prop: 'interFaceStatus',
            search: true,
            sortable:true,
            width: 120,
            html:true,
            align:'center',
            type:'select',
            searchLabelWidth:130,
            dicData: [{key:'true',value:'是'},{key:'false',value:'否'}],
            props: {
              label: "value",
              value: "key"
            },
            formatter : function (row, column) {
              return row.interFaceStatus == 'true' || row.interFaceStatus == '1' ? '<i class="el-icon-check" style="color: limegreen;font-size: 20px;font-weight: 800"></i>' : '<i class="el-icon-close" style="color: red;font-size: 20px;font-weight: 800"></i>'
            }
          },
        ]
      }
    }
  },
  computed:{
    ...mapGetters([ "permission"]),
    permissionList() {
      return {
        addBtn: false,
        viewBtn: false,
        delBtn: false,
        editBtn: false
      };
    }
  },
  methods: {
    searchReset() {
      this.query = {};
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page);
      done();
    },
    selectionChange(list) {
      this.selectionList = list;
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page);
    },
    onLoad(page, params={}) {
      this.loading = true;
      var query={}
      if (this.query) {
        for (var key in this.query) {
          query['conditionMap["' + key + '"]'] = this.query[key];
        }
      }
      getList(page.currentPage, page.pageSize, Object.assign(params,this.params, query,this.query)).then(res => {
        const data = res.data.data;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
        this.selectionClear();
      }).catch(error=>{
        this.$message.error(error);
        this.loading = false;
      });
    }
  }

}
</script>

<style scoped>

</style>
